diff --git a/twitter_block.module b/twitter_block.module
index f3bfdbb..a104f30 100644
--- a/twitter_block.module
+++ b/twitter_block.module
@@ -188,7 +188,7 @@ function twitter_block_block_save($delta = '', $edit = array()) {
   /*
    * More broken dynamic form bits.
 
-  // Map public_timeline checkbox to search_type expected by TwitterSearch
+  // Map public_timeline checkbox to search_type expected by TwitterBlockSearch
   if ($edit['public_timeline'] === 'TRUE' ) {
   $edit['search_type'] = 'searchHashtag';
   } //*/
@@ -222,7 +222,7 @@ function twitter_block_block_view($delta) {
 
 /**
  * Grab data from Twitter, store it for later.
- * @param $config An array suitable for passing to the TwitterSearch object.
+ * @param $config An array suitable for passing to the TwitterBlockSearch object.
  * @return Themed output.
  */
 function twitter_block_load_tweets($config) {
@@ -233,7 +233,7 @@ function twitter_block_load_tweets($config) {
   $cache_bin = 'cache';
 
   // Build the object.
-  $twitter = new TwitterSearch($config);
+  $twitter = new TwitterBlockSearch($config);
 
   // We cache response even if it's empty so an empty response cannot cause a
   // performance problem by making us contact Twitter in every request

diff --git a/twitter_block.class.php b/twitter_block.class.php
index bdcfdf2..9679afc 100644
--- a/twitter_block.class.php
+++ b/twitter_block.class.php
@@ -12,11 +12,11 @@
  */
 
 /**
  * TwitterSearch provides the class for using the Twitter Search API.
  *
  * For more information on the API, see http://dev.twitter.com/doc/get/search
  */
-class TwitterSearch {
+class TwitterBlockSearch {
 
   // HTTP status code returned
   private $http_status;
@@ -12,11 +12,11 @@
 
 /**
- * TwitterSearch provides the class for using the Twitter Search API.
+ * TwitterBlockSearch provides the class for using the Twitter Search API.
  *
  * For more information on the API, see http://dev.twitter.com/doc/get/search